==> cueplot-0.0.2-src.tar.gz: cueplot-0.0.2-src/gui/opt/terminal/TerminalLatexEmtexOptionWidget.h <==
/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED
#define TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"
class TerminalLatexEmtex;

class QComboBox;
class QSpinBox;

class TerminalLatexEmtexOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		TerminalLatexEmtexOptionWidget(QWidget *parent = 0);
		~TerminalLatexEmtexOptionWidget();

		void construct();

	protected:
		virtual void init();
		TerminalLatexEmtex *terminalLatexEmtex;

	private:
		// don't implement these
		TerminalLatexEmtexOptionWidget(const TerminalLatexEmtexOptionWidget &);
		TerminalLatexEmtexOptionWidget &operator=(const TerminalLatexEmtexOptionWidget &);

		void apply();
		void setWidget();
		QComboBox *fontNameComboBox;
		QSpinBox *fontSizeSpinBox;
};
#endif // TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED

==> cueplot-0.0.3-src.tar.gz: cueplot-0.0.3-src/gui/opt/terminal/TerminalLatexEmtexOptionWidget.h <==
/*
 * Cueplot: a GUI front-end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED
#define TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED

#include "OptionWidget.h"
class TerminalLatexEmtex;

class QComboBox;
class QSpinBox;

class TerminalLatexEmtexOptionWidget : public OptionWidget
{
	Q_OBJECT

	public:
		explicit TerminalLatexEmtexOptionWidget(QWidget *parent = 0);
		~TerminalLatexEmtexOptionWidget();

		void construct();

	protected:
		virtual void init();
		TerminalLatexEmtex *terminalLatexEmtex;

	private:
		// don't implement these
		TerminalLatexEmtexOptionWidget(const TerminalLatexEmtexOptionWidget &);
		TerminalLatexEmtexOptionWidget &operator=(const TerminalLatexEmtexOptionWidget &);

		void apply();
		void setWidget();
		QComboBox *fontNameComboBox;
		QSpinBox *fontSizeSpinBox;
};
#endif // TERMINAL_LATEX_EMTEX_OPTION_WIDGET_INCLUDED
